==> haskell-libxml-sax-0.7.5-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libxml-sax.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libxml-sax
version: 0.7.5
id: libxml-sax-0.7.5-CZNJ7yMYetWDObZtx2BxlB
key: libxml-sax-0.7.5-CZNJ7yMYetWDObZtx2BxlB
license: MIT
maintainer: jmillikin@gmail.com
stability: experimental
homepage: https://john-millikin.com/software/haskell-libxml/
synopsis: Bindings for the libXML2 SAX interface
category: Foreign, Text, XML, Parsing
author: John Millikin
exposed: True
indefinite: False
exposed-modules:
    Text.XML.LibXML.SAX
abi: 645c9673eadf15561f992fe95c64419d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/libxml-sax-0.7.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/libxml-sax-0.7.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/libxml-sax-0.7.5
hs-libraries: HSlibxml-sax-0.7.5-CZNJ7yMYetWDObZtx2BxlB
extra-libraries:
    xml2 xml2
include-dirs: /usr/include/libxml2
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    xml-types-0.3.6-8U94ZZax169GYLVDpT1mig
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             xml-types-0.3.6-8U94ZZax169GYLVDpT1mig=66a00e6b1ab0a96693d6da0f27af76bf
haddock-interfaces: /usr/share/doc/haskell-libxml-sax/html/libxml-sax.haddock
haddock-html: /usr/share/doc/haskell-libxml-sax/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libxml-sax-0.7.5-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libxml-sax.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libxml-sax
version: 0.7.5
id: libxml-sax-0.7.5-FejhMvuTvxT64dOEVQOQrU
key: libxml-sax-0.7.5-FejhMvuTvxT64dOEVQOQrU
license: MIT
maintainer: jmillikin@gmail.com
stability: experimental
homepage: https://john-millikin.com/software/haskell-libxml/
synopsis: Bindings for the libXML2 SAX interface
category: Foreign, Text, XML, Parsing
author: John Millikin
exposed: True
indefinite: False
exposed-modules:
    Text.XML.LibXML.SAX
abi: 7bf5d226f2215e913eac1b9852a4b6f7
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/libxml-sax-0.7.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/libxml-sax-0.7.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/libxml-sax-0.7.5
hs-libraries: HSlibxml-sax-0.7.5-FejhMvuTvxT64dOEVQOQrU
extra-libraries:
    xml2 xml2
include-dirs: /usr/include/libxml2
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    xml-types-0.3.6-8WPJEemJnrZwepJreraPY
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             xml-types-0.3.6-8WPJEemJnrZwepJreraPY=7e7faac838649cb4151c9d4e8edfc9dc
haddock-interfaces: /usr/share/doc/haskell-libxml-sax/html/libxml-sax.haddock
haddock-html: /usr/share/doc/haskell-libxml-sax/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
